@@ -46,8 +46,11 @@ my $m = DBIx::Migration->new(
 $m->migrate( $ARGV[2] );
 
 1;
+
 __END__
 
+=pod
+
 =head1 NAME
 
 dbix-migration - Seamless DB up- and downgrades
@@ -77,7 +80,7 @@ L<DBIx::Migration>
 
 =head1 AUTHOR
 
-Sebastian Riedel, C<sri@oook.de>
+Sebastian Riedel, <kraihx@gmail.com>
 
 =head1 COPYRIGHT
 
